import asyncio
from .hotel_management.reservations import Reservation, ReservationSystem
from .hotel_management.customers import Customer, CustomerManagement
from .hotel_management.rooms import Room, RoomManagement
from .hotel_management.payments import process_payment
from datetime import datetime

async def main():
    # Inicializar sistemas
    reservation_system = ReservationSystem()
    customer_mgmt = CustomerManagement()
    room_mgmt = RoomManagement()

    # Crear habitaciones
    room1 = Room(101,'Single', 100)
    room2 = Room(102,'Double', 200)
    room_mgmt.add_room(room1)
    room_mgmt.add_room(room2)
    # Agregar clientes
    customer1 = Customer(1, "Alice", "alice@example.com")
    customer2 = Customer(2, "Juan", "juan@example.com")
    customer_mgmt.add_customer(customer1)
    customer_mgmt.add_customer(customer2)

    # Verificar disponibilidad de habitaciones
    if room_mgmt.check_availability(101):
        reservation1 = Reservation(1,'Alice', 101, datetime.now(), datetime.now())
        reservation_system.add_reservation(reservation1)
        # Procesar pago asincrónicamente
        await process_payment('Alice', 100)
        room_mgmt.update_availability(101)

    # Verificar disponibilidad de habitaciones
    if room_mgmt.check_availability(102):
        reservation2 = Reservation(2,'Juan', 102, datetime.now(), datetime.now())
        reservation_system.add_reservation(reservation2)
        # Procesar pago asincrónicamente
        await process_payment('Juan', 200)
        room_mgmt.update_availability(102)
    # cancelar una reserva
    reservation_system.cancel_reservation(2)
    room_mgmt.update_availability(102)
    # cancelar una reserva inexistente
    reservation_system.cancel_reservation(4)

if __name__ == "__main__":
    asyncio.run(main())




import asyncio
import random

async def process_payment(customer_name, amount):
    """Simula el procesamiento de un pago."""
    print(f'Procesando el pago del cliente {customer_name} por valor de ${amount}')
    await asyncio.sleep(random.randint(1,3)) # simular tiempo de procesar pago
    print(f'Pago completado para el cliente {customer_name} por valor de ${amount}')
    return True



from setuptools import setup, find_packages

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setup(
    name="pkg_platzi_final",
    version="0.4.0",
    author="odelgado",
    author_email="odelgadoo@gmail.com",
    description="Un sistema básico de gestión de reservas en Python",
    long_description=long_description,
    long_description_content_type="text/markdown",  # Indica que el README está en formato Markdown
    url="https://github.com/Odelgadoo/pkg_platzi_final",
    packages=find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.10',
)